
/* A list of old or current members. */
div.fui-members {
}

div.fui-members-old div.fui-member-card {
	border: 1px dashed #555;
}


div.fui-members h2 {
	clear: left;

	/* Need to use padding instead of margin because of float */
	padding-top: 30px;
	margin-top: 0;
}

/* Information + portrait */
div.fui-member-card {
	padding: 10px;
	float: left;
	position: relative;
	border: 1px solid #000;
	width: 300px;
	height: 110px;
	margin: 10px;
	overflow: auto;
}

img.fui-member-portrait {
	float: left;
	display: block;
}

/* The information about a member */
div.fui-member-info {
	margin-left: 100px;
}

/* Name of member */
.fui-member-info h3 {
	margin: 0 0 10px 0;
	padding: 0;
	font-size: 1.2em;
}

/* Name of member */
.fui-member-info h3 {
	margin: 0 0 10px 0;
	padding: 0;
	font-size: 1.2em;
}


.fui-member-description {
	font-size: 0.9em;
	margin: 4px 0 4px 0;
	color: #333;
}
